@@ -5,9 +5,9 @@ import atexit
 import threading
 import subprocess
 from typing import Any
-
 from vertx import EventBus
 from queue import Queue
+import traceback
 
 class ServiceError(Exception):
     def __init__(self, body:dict):
@@ -73,6 +73,8 @@ class BPMService:
         self.eb_calls.send(address=addr, headers=headers, body=body)
 
     def fail(self, message: str = None, address=None, headers=None):
+        if message is None:
+            message=traceback.format_exc()
         addr = self.getAddress(address)
         body = {"error": message, "succeeded":False}
         self.eb_calls.send(address=addr, headers=headers, body=body)
