@@ -54,6 +54,9 @@ class Service:
             "target": target,
             "sound": sound})
 
+    def env(self) -> dict:
+        return self.bpm.call("EBHBPMService.env", body={})
+
     def now(self):
         return self.bpm.call("EBHBPMService.now", body={})
 
